@@ -1,5 +1,7 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+from . import rowingdata
 from sys import argv
 
 def main():
@@ -22,8 +24,8 @@ def main():
 
     res.plotmeters_erg()
 
-    print(res.allstats())
+    print((res.allstats()))
 
 
 
-    print("done "+readFile)
+    print(("done "+readFile))
